@@ -5,25 +5,32 @@
 from urlparse import urlsplit
 import re
 from grab.tools.lxml_tools import clean_html
+import transliterate
+from transliterate.utils import translit
 
 from django.db import models
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
+from django.utils.text import slugify
+
+from taggit.managers import TaggableManager
+from taggit.models import GenericTaggedItemBase, TagBase
+
+transliterate.autodiscover()
 
-from tagging.fields import TagField
 
 class Feed(models.Model):
     title = models.CharField(_('title'), max_length=255)
     feed_url = models.CharField(_('feed url'), max_length=255, unique=True)
     site_url = models.CharField(_('site url'), max_length=255)
-    active = models.BooleanField(_('active'), blank=True, default=True)
+    active = models.BooleanField(_('active'), blank=True, default=True, db_index=True)
     etag = models.CharField(u'ETag', max_length=255, blank=True, default='')
     last_checked = models.DateTimeField(_('last checked'), blank=True, null=True)
     skip_filters = models.BooleanField(_('allow all messages'), blank=True, default=False)
     author = models.CharField(_('blog author'), blank=True, max_length=255)
     created = models.DateTimeField(_('Date of submition'), blank=True, null=True,
-                                   auto_now_add=True)
+                                   auto_now_add=True, db_index=True)
     post_count = models.IntegerField(blank=True, default=0)
     active_post_count = models.IntegerField(blank=True, default=0)
 
@@ -54,6 +61,22 @@ class ActivePostManager(models.Manager):
         return super(ActivePostManager, self).get_query_set().filter(active=True)
 
 
+class FeedzillaTag(TagBase):
+    """
+    Custom version of Tag that
+    knows how to bild slugs for Russian words
+    """
+    def slugify(self, tag, i=None):
+            slug = slugify(translit(tag, 'ru', reversed=True))
+            if i is not None:
+                slug += "-%d" % i
+            return slug
+
+
+class FeedzillaTagItem(GenericTaggedItemBase):
+    tag = models.ForeignKey(FeedzillaTag, related_name='items')
+
+
 class Post(models.Model):
     feed = models.ForeignKey(Feed, verbose_name=_('feed'), related_name='posts')
     title = models.CharField(_('title'), max_length=255)
@@ -62,11 +85,12 @@ class Post(models.Model):
     content = models.TextField(_('content'), blank=True)
     created = models.DateTimeField(_('creation time'))
     guid = models.CharField(_('identifier'), max_length=255, unique=True)
-    tags = TagField()
     active = models.BooleanField(_('active'), blank=True, default=True)
 
     objects = models.Manager()
     active_objects = ActivePostManager()
+    tags = TaggableManager(through=FeedzillaTagItem)
+    rawtags = models.CharField(max_length=255)
 
     class Meta:
         ordering = ['-created']
@@ -109,10 +133,10 @@ class FilterWord(models.Model):
 
 
 class Request(models.Model):
-    url = models.CharField(u'Адрес блога', max_length=255, unique=True)
-    title = models.CharField(u'Название блога', max_length=255)
-    author = models.CharField(u'Имя Фамилия автора блога', blank=True, max_length=50)
-    feed_url = models.CharField(u'URL фида', blank=True, max_length=255, help_text=u'Вы можете указать, какой именно RSS/Atom фид вы хотите добавить')
+    url = models.CharField(_('Blog URL'), max_length=255, unique=True)
+    title = models.CharField(_('Blog name'), max_length=255)
+    author = models.CharField(_('Name of author of the blog'), blank=True, max_length=50)
+    feed_url = models.CharField(_('Feed URL'), blank=True, max_length=255, help_text=_('You can specify what exactly feed you want submit'))
     created = models.DateTimeField(_('Creation date'), auto_now_add=True)
 
     def __unicode__(self):
